# openapi-client
MoneyBox will help you better understand your finances, improve financial literacy, and achieve financial goals.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import openapi_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openapi_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: APIAuthentication
configuration.api_key['APIAuthentication'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['APIAuthentication'] = 'Bearer'


# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.AuthApi(api_client)

    try:
        api_response = api_instance.auth_get_token_retrieve()
        print("The response of AuthApi->auth_get_token_retrieve:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AuthApi->auth_get_token_retrieve: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthApi* | [**auth_get_token_retrieve**](docs/AuthApi.md#auth_get_token_retrieve) | **GET** /api/v1/auth/get_token/ | 
*AuthApi* | [**auth_signin_create**](docs/AuthApi.md#auth_signin_create) | **POST** /api/v1/auth/signin/ | 
*AuthApi* | [**auth_signup_create**](docs/AuthApi.md#auth_signup_create) | **POST** /api/v1/auth/signup/ | 
*CurrencyApi* | [**currency_create**](docs/CurrencyApi.md#currency_create) | **POST** /api/v1/currency/ | 
*CurrencyApi* | [**currency_destroy**](docs/CurrencyApi.md#currency_destroy) | **DELETE** /api/v1/currency/{id}/ | 
*CurrencyApi* | [**currency_list**](docs/CurrencyApi.md#currency_list) | **GET** /api/v1/currency/ | 
*CurrencyApi* | [**currency_partial_update**](docs/CurrencyApi.md#currency_partial_update) | **PATCH** /api/v1/currency/{id}/ | 
*CurrencyApi* | [**currency_retrieve**](docs/CurrencyApi.md#currency_retrieve) | **GET** /api/v1/currency/{id}/ | 
*CurrencyApi* | [**currency_update**](docs/CurrencyApi.md#currency_update) | **PUT** /api/v1/currency/{id}/ | 
*CurrencyApi* | [**currencyrate_create**](docs/CurrencyApi.md#currencyrate_create) | **POST** /api/v1/currencyrate/ | 
*CurrencyApi* | [**currencyrate_destroy**](docs/CurrencyApi.md#currencyrate_destroy) | **DELETE** /api/v1/currencyrate/{id}/ | 
*CurrencyApi* | [**currencyrate_get_rate_retrieve**](docs/CurrencyApi.md#currencyrate_get_rate_retrieve) | **GET** /api/v1/currencyrate/get_rate/ | 
*CurrencyApi* | [**currencyrate_list**](docs/CurrencyApi.md#currencyrate_list) | **GET** /api/v1/currencyrate/ | 
*CurrencyApi* | [**currencyrate_partial_update**](docs/CurrencyApi.md#currencyrate_partial_update) | **PATCH** /api/v1/currencyrate/{id}/ | 
*CurrencyApi* | [**currencyrate_retrieve**](docs/CurrencyApi.md#currencyrate_retrieve) | **GET** /api/v1/currencyrate/{id}/ | 
*CurrencyApi* | [**currencyrate_update**](docs/CurrencyApi.md#currencyrate_update) | **PUT** /api/v1/currencyrate/{id}/ | 
*ExpensesApi* | [**expense_create**](docs/ExpensesApi.md#expense_create) | **POST** /api/v1/expense/ | 
*ExpensesApi* | [**expense_destroy**](docs/ExpensesApi.md#expense_destroy) | **DELETE** /api/v1/expense/{id}/ | 
*ExpensesApi* | [**expense_list**](docs/ExpensesApi.md#expense_list) | **GET** /api/v1/expense/ | 
*ExpensesApi* | [**expense_partial_update**](docs/ExpensesApi.md#expense_partial_update) | **PATCH** /api/v1/expense/{id}/ | 
*ExpensesApi* | [**expense_retrieve**](docs/ExpensesApi.md#expense_retrieve) | **GET** /api/v1/expense/{id}/ | 
*ExpensesApi* | [**expense_update**](docs/ExpensesApi.md#expense_update) | **PUT** /api/v1/expense/{id}/ | 
*ExpensesApi* | [**expensecategory_create**](docs/ExpensesApi.md#expensecategory_create) | **POST** /api/v1/expensecategory/ | 
*ExpensesApi* | [**expensecategory_destroy**](docs/ExpensesApi.md#expensecategory_destroy) | **DELETE** /api/v1/expensecategory/{id}/ | 
*ExpensesApi* | [**expensecategory_list**](docs/ExpensesApi.md#expensecategory_list) | **GET** /api/v1/expensecategory/ | 
*ExpensesApi* | [**expensecategory_partial_update**](docs/ExpensesApi.md#expensecategory_partial_update) | **PATCH** /api/v1/expensecategory/{id}/ | 
*ExpensesApi* | [**expensecategory_retrieve**](docs/ExpensesApi.md#expensecategory_retrieve) | **GET** /api/v1/expensecategory/{id}/ | 
*ExpensesApi* | [**expensecategory_update**](docs/ExpensesApi.md#expensecategory_update) | **PUT** /api/v1/expensecategory/{id}/ | 
*IncomesApi* | [**income_create**](docs/IncomesApi.md#income_create) | **POST** /api/v1/income/ | 
*IncomesApi* | [**income_destroy**](docs/IncomesApi.md#income_destroy) | **DELETE** /api/v1/income/{id}/ | 
*IncomesApi* | [**income_list**](docs/IncomesApi.md#income_list) | **GET** /api/v1/income/ | 
*IncomesApi* | [**income_partial_update**](docs/IncomesApi.md#income_partial_update) | **PATCH** /api/v1/income/{id}/ | 
*IncomesApi* | [**income_retrieve**](docs/IncomesApi.md#income_retrieve) | **GET** /api/v1/income/{id}/ | 
*IncomesApi* | [**income_update**](docs/IncomesApi.md#income_update) | **PUT** /api/v1/income/{id}/ | 
*IncomesApi* | [**incomecategory_create**](docs/IncomesApi.md#incomecategory_create) | **POST** /api/v1/incomecategory/ | 
*IncomesApi* | [**incomecategory_destroy**](docs/IncomesApi.md#incomecategory_destroy) | **DELETE** /api/v1/incomecategory/{id}/ | 
*IncomesApi* | [**incomecategory_list**](docs/IncomesApi.md#incomecategory_list) | **GET** /api/v1/incomecategory/ | 
*IncomesApi* | [**incomecategory_partial_update**](docs/IncomesApi.md#incomecategory_partial_update) | **PATCH** /api/v1/incomecategory/{id}/ | 
*IncomesApi* | [**incomecategory_retrieve**](docs/IncomesApi.md#incomecategory_retrieve) | **GET** /api/v1/incomecategory/{id}/ | 
*IncomesApi* | [**incomecategory_update**](docs/IncomesApi.md#incomecategory_update) | **PUT** /api/v1/incomecategory/{id}/ | 
*InvitesApi* | [**invite_create**](docs/InvitesApi.md#invite_create) | **POST** /api/v1/invite/ | 
*ReportsApi* | [**report_html_retrieve**](docs/ReportsApi.md#report_html_retrieve) | **GET** /api/v1/report/html/ | 
*ReportsApi* | [**report_list**](docs/ReportsApi.md#report_list) | **GET** /api/v1/report/ | 
*TransfersApi* | [**transfer_create**](docs/TransfersApi.md#transfer_create) | **POST** /api/v1/transfer/ | 
*TransfersApi* | [**transfer_destroy**](docs/TransfersApi.md#transfer_destroy) | **DELETE** /api/v1/transfer/{id}/ | 
*TransfersApi* | [**transfer_list**](docs/TransfersApi.md#transfer_list) | **GET** /api/v1/transfer/ | 
*TransfersApi* | [**transfer_partial_update**](docs/TransfersApi.md#transfer_partial_update) | **PATCH** /api/v1/transfer/{id}/ | 
*TransfersApi* | [**transfer_retrieve**](docs/TransfersApi.md#transfer_retrieve) | **GET** /api/v1/transfer/{id}/ | 
*TransfersApi* | [**transfer_update**](docs/TransfersApi.md#transfer_update) | **PUT** /api/v1/transfer/{id}/ | 
*UsersApi* | [**user_create**](docs/UsersApi.md#user_create) | **POST** /api/v1/user/ | 
*UsersApi* | [**user_destroy**](docs/UsersApi.md#user_destroy) | **DELETE** /api/v1/user/{id}/ | 
*UsersApi* | [**user_list**](docs/UsersApi.md#user_list) | **GET** /api/v1/user/ | 
*UsersApi* | [**user_partial_update**](docs/UsersApi.md#user_partial_update) | **PATCH** /api/v1/user/{id}/ | 
*UsersApi* | [**user_retrieve**](docs/UsersApi.md#user_retrieve) | **GET** /api/v1/user/{id}/ | 
*UsersApi* | [**user_update**](docs/UsersApi.md#user_update) | **PUT** /api/v1/user/{id}/ | 
*WalletsApi* | [**wallet_create**](docs/WalletsApi.md#wallet_create) | **POST** /api/v1/wallet/ | 
*WalletsApi* | [**wallet_destroy**](docs/WalletsApi.md#wallet_destroy) | **DELETE** /api/v1/wallet/{id}/ | 
*WalletsApi* | [**wallet_list**](docs/WalletsApi.md#wallet_list) | **GET** /api/v1/wallet/ | 
*WalletsApi* | [**wallet_partial_update**](docs/WalletsApi.md#wallet_partial_update) | **PATCH** /api/v1/wallet/{id}/ | 
*WalletsApi* | [**wallet_retrieve**](docs/WalletsApi.md#wallet_retrieve) | **GET** /api/v1/wallet/{id}/ | 
*WalletsApi* | [**wallet_update**](docs/WalletsApi.md#wallet_update) | **PUT** /api/v1/wallet/{id}/ | 
*GroupApi* | [**group_create**](docs/GroupApi.md#group_create) | **POST** /api/v1/group/ | 
*GroupApi* | [**group_destroy**](docs/GroupApi.md#group_destroy) | **DELETE** /api/v1/group/{id}/ | 
*GroupApi* | [**group_list**](docs/GroupApi.md#group_list) | **GET** /api/v1/group/ | 
*GroupApi* | [**group_partial_update**](docs/GroupApi.md#group_partial_update) | **PATCH** /api/v1/group/{id}/ | 
*GroupApi* | [**group_retrieve**](docs/GroupApi.md#group_retrieve) | **GET** /api/v1/group/{id}/ | 
*GroupApi* | [**group_update**](docs/GroupApi.md#group_update) | **PUT** /api/v1/group/{id}/ | 


## Documentation For Models

 - [APIUser](docs/APIUser.md)
 - [Currency](docs/Currency.md)
 - [CurrencyRate](docs/CurrencyRate.md)
 - [Expense](docs/Expense.md)
 - [ExpenseCategory](docs/ExpenseCategory.md)
 - [Group](docs/Group.md)
 - [Income](docs/Income.md)
 - [IncomeCategory](docs/IncomeCategory.md)
 - [Invite](docs/Invite.md)
 - [PaginatedAPIUserList](docs/PaginatedAPIUserList.md)
 - [PaginatedCurrencyList](docs/PaginatedCurrencyList.md)
 - [PaginatedCurrencyRateList](docs/PaginatedCurrencyRateList.md)
 - [PaginatedExpenseCategoryList](docs/PaginatedExpenseCategoryList.md)
 - [PaginatedExpenseList](docs/PaginatedExpenseList.md)
 - [PaginatedGroupList](docs/PaginatedGroupList.md)
 - [PaginatedIncomeCategoryList](docs/PaginatedIncomeCategoryList.md)
 - [PaginatedIncomeList](docs/PaginatedIncomeList.md)
 - [PaginatedTransferList](docs/PaginatedTransferList.md)
 - [PaginatedWalletList](docs/PaginatedWalletList.md)
 - [PatchedAPIUser](docs/PatchedAPIUser.md)
 - [PatchedCurrency](docs/PatchedCurrency.md)
 - [PatchedCurrencyRate](docs/PatchedCurrencyRate.md)
 - [PatchedExpense](docs/PatchedExpense.md)
 - [PatchedExpenseCategory](docs/PatchedExpenseCategory.md)
 - [PatchedGroup](docs/PatchedGroup.md)
 - [PatchedIncome](docs/PatchedIncome.md)
 - [PatchedIncomeCategory](docs/PatchedIncomeCategory.md)
 - [PatchedTransfer](docs/PatchedTransfer.md)
 - [PatchedWallet](docs/PatchedWallet.md)
 - [Report](docs/Report.md)
 - [Signup](docs/Signup.md)
 - [Transfer](docs/Transfer.md)
 - [Wallet](docs/Wallet.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="APIAuthentication"></a>
### APIAuthentication

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




